@@ -7,9 +7,10 @@ from nlpkit.parse.mate import parse, MateParser
 
 parser = argparse.ArgumentParser(description="Lemmatizes, tags and parses raw text with the mate-tools parser")
 parser.add_argument('in_file', help="Raw text with one document per line. Assumed to be in UTF-8")
-parser.add_argument('--out_file', '-o', help='Processed text in CONLL9 format', required=True)
-parser.add_argument('--map_file', '-m', help='Mapping between sentences and documents', required=True)
+parser.add_argument('--out_file', '-o', help='Processed text in CONLL9 format. Default is to append .conll9')
+parser.add_argument('--map_file', '-m', help='Mapping between sentences and documents. Default is to append .map')
 parser.add_argument('--mate-dir', help='Path to the mate parser')
+parser.add_argument('--only-tag', '-t', help="Just tagging", action='store_true')
 args = parser.parse_args()
 
 logging.basicConfig(format='%(asctime)s : %(levelname)s : %(message)s', level=logging.INFO)
@@ -26,7 +27,8 @@ if not args.mate_dir:
 else:
     mate_dir = args.mate_dir
 
+out_fname = args.out_file if args.out_file else args.in_file + ".conll9"
+map_fname = args.map_file if args.map_file else args.in_file + ".map"
 
-
-docs =  (line.strip() for line in codecs.open(args.in_file, encoding='utf-8', errors='ignore'))
-parse(docs, args.out_file, args.map_file, parser=MateParser(mate_dir=mate_dir))
+docs = (line.strip() for line in codecs.open(args.in_file, encoding='utf-8', errors='ignore'))
+parse(docs, out_fname, map_fname, parser=MateParser(mate_dir=mate_dir), only_tag=args.only_tag)
\ No newline at end of file
